@@ -35,6 +35,10 @@ class Registry(LoggerAware):
         if not issubclass(entity, ffd.AggregateRoot):
             raise ffd.LogicError('Repositories can only be generated for aggregate roots')
 
+        for k, v in self._cache.items():
+            if entity.same_type(k):
+                return v
+
         if entity not in self._cache:
             for k, v in self._factories.items():
                 if issubclass(entity, k):
@@ -44,6 +48,7 @@ class Registry(LoggerAware):
                     self._cache[entity] = v(k)
                     break
 
+        if entity not in self._cache:
             context = entity.get_class_context()
             if context in self._default_factory and self._default_factory[context] is not None:
                 self._cache[entity] = self._default_factory[context](entity)
@@ -56,7 +61,14 @@ class Registry(LoggerAware):
         return self._cache[entity]
 
     def register_factory(self, type_: Type[AR], factory: ffd.RepositoryFactory):
-        self._factories[type_] = factory
+        found = False
+        for entity in self._factories.keys():
+            if type_.same_type(entity):
+                found = True
+                break
+
+        if not found:
+            self._factories[type_] = factory
 
     def set_default_factory(self, context: str, factory: ffd.RepositoryFactory):
         self._default_factory[context] = factory
